@@ -1,7 +1,5 @@
 import inspect
-import sys
 import re
-import traceback
 from functools import wraps
 from velocity.db import exceptions
 from velocity.db.core.transaction import Transaction
@@ -176,18 +174,18 @@ class Engine:
                 while True:
                     try:
                         return function(*args, **kwds)
-                    except exceptions.DbRetryTransaction as e:
+                    except exceptions.DbRetryTransaction:
                         retry_count += 1
                         if retry_count > self.MAX_RETRIES:
                             raise
                         _tx.rollback()
-                    except exceptions.DbLockTimeoutError as e:
+                    except exceptions.DbLockTimeoutError:
                         lock_timeout_count += 1
                         if lock_timeout_count > self.MAX_RETRIES:
                             raise
                         _tx.rollback()
                         continue
-                    except:
+                    except Exception:
                         raise
         finally:
             setattr(_tx, "_exec_function_depth", depth)
