@@ -54,13 +54,13 @@ class Table:
         """
         try:
             self._cursor.close()
-        except:
+        except Exception:
             pass
 
     def cursor(self):
         try:
             return self._cursor
-        except:
+        except AttributeError:
             pass
         self._cursor = self.tx.cursor()
         return self._cursor
@@ -887,8 +887,8 @@ class Table:
         # Return a descriptive string of differences.
         if differences:
             differences.insert(0, f"Comparing {self.name}: {pk1} vs {pk2}")
-            differences.insert(0, f"--------------------------------------")
-            differences.append(f"--------------------------------------")
+            differences.insert(0, "--------------------------------------")
+            differences.append("--------------------------------------")
             return "\n".join(differences)
         else:
             return f"{self.name} rows {pk1} and {pk2} are identical."
