@@ -30,7 +30,7 @@ def make_where(where, sql, vals, is_join=False):
             if is_join:
                 if "." not in key:
                     key = "A." + key
-            if val == None:
+            if val is None:
                 if "!" in key:
                     key = key.replace("!", "")
                     sql.append("{} is not NULL".format(quote(key.lower())))
@@ -144,6 +144,10 @@ class SQL:
     LockTimeoutErrorCodes = []
     DatabaseObjectExistsErrorCodes = []
 
+    def get_error(self, e):
+        error_code, error_mesg = e.args[:2]
+        return error_code, error_mesg
+
     @classmethod
     def __has_pointer(cls, columns):
         if columns:
@@ -194,7 +198,7 @@ class SQL:
         cls, table, columns, key_to_table, key_to_columns, name=None, schema=None
     ):
         if "." not in table and schema:
-            if schema == None:
+            if schema is None:
                 schema = cls.default_schema
             table = "{}.{}".format(schema, table)
         if isinstance(key_to_columns, str):
@@ -250,7 +254,6 @@ class SQL:
 
     @classmethod
     def create_table(cls, name, columns={}, drop=False):
-        trigger = "".format(name)
         sql = []
         if drop:
             sql.append(cls.drop_table(name))
